How to clean the experiment — autosubmit 3.9.1 documentation

# How to clean the experiment

This procedure allows you to save space after finalising an experiment. You must execute:

    autosubmit clean EXPID

Options:

    usage: autosubmit clean [-h] [-pr] [-p] [-s] expid

      expid           experiment identifier

      -h, --help      show this help message and exit
      -pr, --project  clean project
      -p, --plot      clean plot, only 2 last will remain
      -s, --stats     clean stats, only last will remain

- The -p and -s flag are used to clean our experiment `plot` folder to save disk space. Only the two latest plots will be kept. Older plots will be removed.

Example:

    autosubmit clean cxxx -p

- The -pr flag is used to clean our experiment `proj` locally in order to save space (it could be particullary big).

Caution

Bear in mind that if you have not synchronized your experiment project folder with the information available on the remote repository (i.e.: commit and push any changes we may have), or in case new files are found, the clean procedure will be failing although you specify the -pr option.

Example:

    autosubmit clean cxxx -pr

A bare copy (which occupies less space on disk) will be automatically made.

Hint

That bare clone can be always reconverted in a working clone if we want to run again the experiment by using `git clone bare_clone original_clone`.

Note

In addition, every time you run this command with -pr option, it will check the commit unique identifier for local working tree existing on the `proj` directory. In case that commit identifier exists, clean will register it to the `expdef_cxxx.conf` file.